==> spip_3.2.11.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Vložiť À',
	'barre_adresse' => 'Adresa',
	'barre_aide' => 'Na úpravu vzhľadu použite klávesové skratky',
	'barre_alignerdroite' => 'Odsek [/zarovnať vpravo/]',
	'barre_ancres' => 'Kotvy',
	'barre_barre' => 'Prečiarknuť text',
	'barre_bulle' => 'Bublinková nápoveď',
	'barre_c_cedille_maj' => 'Vložiť Ç',
	'barre_cadre' => 'Dať do &lt;rámu&gt; textového poľa&lt;/rámu&gt;',
	'barre_caracteres' => 'Špeciálne znaky',
	'barre_centrer' => 'Zarovnať odsek [|nastred|]',
	'barre_chercher' => 'Vyhľadať a nahradiť',
	'barre_clean' => 'Vyčistiť kód od všetkých tagov HTML',
	'barre_code' => 'Upraviť &lt;kód&gt;počítačový kód&lt;/kód&gt;',
	'barre_desindenter' => 'Zrušiť voľný riadok',
	'barre_e_accent_aigu' => 'Vložiť É',
	'barre_e_accent_grave' => 'Vložiť È',
	'barre_ea' => 'Vložiť æ',
	'barre_ea_maj' => 'Vložiť Æ',
	'barre_encadrer' => '[(Orámovať)] odsek',
	'barre_eo' => 'Vložiť œ',
	'barre_eo_maj' => 'Vložiť Œ',
	'barre_euro' => 'Vložiť symbol €',
	'barre_exposant' => 'Zmeniť text na &lt;sup&gt;horný index&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Špeciálne formátovanie',
	'barre_galerie' => 'Otvoriť galériu',
	'barre_gestion_anc_bulle' => 'Bublina s nápoveďou ku kotve',
	'barre_gestion_anc_caption' => 'Kotvy',
	'barre_gestion_anc_cible' => 'Cieľ kotvy',
	'barre_gestion_anc_inserer' => 'Zmeniť na kotvu',
	'barre_gestion_anc_nom' => 'Názov kotvy',
	'barre_gestion_anc_pointer' => 'Prepojiť s kotvou',
	'barre_gestion_caption' => 'Legenda a zhrnutie',
	'barre_gestion_colonne' => 'Počet stĺpcov',
	'barre_gestion_cr_casse' => 'Rozlišovať malé a veľké písmená',
	'barre_gestion_cr_changercasse' => 'Zmeniť malé písmená na veľké alebo opačne',
	'barre_gestion_cr_changercassemajuscules' => 'Zmeniť na veľké písmená',
	'barre_gestion_cr_changercasseminuscules' => 'Zmeniť na malé písmená',
	'barre_gestion_cr_chercher' => 'Vyhľadať',
	'barre_gestion_cr_entier' => 'Iba celé slová',
	'barre_gestion_cr_remplacer' => 'Nahradiť',
	'barre_gestion_cr_tout' => 'Nahradiť všetky',
	'barre_gestion_entete' => 'Hlavička',
	'barre_gestion_ligne' => 'Počet riadkov',
	'barre_gestion_taille' => 'Pevná veľkosť',
	'barre_glossaire' => 'Odkaz na [?Slovník] (Wikipédia)',
	'barre_gras' => '{{Tučné písmo}}',
	'barre_guillemets' => 'Dať do "dvojitých úvodzoviek"',
	'barre_guillemets_simples' => 'Dať do “jednoduchých úvodzoviek“',
	'barre_indenter' => 'Vynechať riadok',
	'barre_inserer_cadre' => 'Vložiť predformátovaný kód (rám)',
	'barre_inserer_caracteres' => 'Vložiť špeciálne znaky',
	'barre_inserer_code' => 'Vložiť počítačový kód (kód)',
	'barre_intertitre' => 'Zmeniť na {{{podnadpis}}}',
	'barre_italic' => '{Kurzíva}',
	'barre_langue' => 'Skratkový jzyk',
	'barre_lien' => 'Zmeniť na [hypertextový odkaz->http://...]',
	'barre_lien_externe' => 'Externý odkaz',
	'barre_lien_input' => 'Prosím, zadajte cieľ svojho hypertextového odkazu (môžete uviesť internetovú adresu v podobe http://www.mojastranka.sk alebo jednoducho číslo článku na tejto stránke).',
	'barre_liste_ol' => 'Nastaviť číslovaný zoznam',
	'barre_liste_ul' => 'Nastaviť zoznam',
	'barre_lorem_ipsum' => 'Vložiť falošný odsek',
	'barre_lorem_ipsum_3' => 'Vložiť tri falošné odseky',
	'barre_miseenevidence' => '[*Zvýrazniť*] text',
	'barre_note' => 'Zmeniť na [[poznámku pod čiarou]]',
	'barre_paragraphe' => 'Vytvoriť odsek',
	'barre_petitescapitales' => 'Zmeniť text na &lt;sc&gt;kapitálky&lt;/sc&gt;',
	'barre_poesie' => 'Upraviť ako &lt;poesie&gt;poéziu&lt;/poesie&gt;',
	'barre_preview' => 'Režim ukážky',
	'barre_quote' => '<quote>Citovať príspevok</quote>',
	'barre_stats' => 'Zobraziť štatistiku textu',
	'barre_tableau' => 'Vložiť/upraviť tabuľku (najprv ju označte)',

	// C
	'config_info_enregistree' => 'Nastavenia uložené',

	// E
	'editer' => 'Upraviť',
	'explication_barre_outils_public' => 'CSS a javascriptové skripty pre panely s nástrojmi
 (Rozšírenie Quill, Porte Plume) sa nachádzajú na verejne prístupnej stránke 
 a poskytujú panely nástrojov v diskusných fórach, vo verejnom prostredí crayonov alebo iných zásuvných modulov
 ak to ich nastavenia povoľujú.',
	'explication_barre_outils_public_2' => 'Môžete sa rozhodnúť, že nebudete spúšťať tieto skripty, aby ste odbremenili verejne prístupné stránky.
Preto bez ohľadu na nastavenia diskusných fóra, crayonov alebo zásuvných modulov
 sa na verejne prístupnej stránke automaticky nezobrazí žiaden panel s nástrojmi Porte Plume.',

	// I
	'info_barre_outils_public' => 'Verejné nástroje',
	'info_porte_plume_titre' => 'Nastavenia nástrojov',

	// L
	'label_barre_outils_public_non' => 'Na verejne prístupnej stránke nespúšťať skripty nástrojov',
	'label_barre_outils_public_oui' => 'Na verejne prístupnej stránke spúšťať skripty nástrojov',

	// V
	'voir' => 'Ukážka'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Vložiť À',
	'barre_adresse' => 'Adresa',
	'barre_aide' => 'Na úpravu vzhľadu použite klávesové skratky',
	'barre_alignerdroite' => 'Odsek [/zarovnať vpravo/]',
	'barre_ancres' => 'Kotvy',
	'barre_barre' => 'Prečiarknuť text',
	'barre_bulle' => 'Bublinková nápoveď',
	'barre_c_cedille_maj' => 'Vložiť Ç',
	'barre_cadre' => 'Dať do &lt;rámu&gt; textového poľa&lt;/rámu&gt;',
	'barre_caracteres' => 'Špeciálne znaky',
	'barre_centrer' => 'Zarovnať odsek [|nastred|]',
	'barre_chercher' => 'Vyhľadať a nahradiť',
	'barre_clean' => 'Vyčistiť kód od všetkých tagov HTML',
	'barre_code' => 'Upraviť &lt;kód&gt;počítačový kód&lt;/kód&gt;',
	'barre_desindenter' => 'Zrušiť voľný riadok',
	'barre_e_accent_aigu' => 'Vložiť É',
	'barre_e_accent_grave' => 'Vložiť È',
	'barre_ea' => 'Vložiť æ',
	'barre_ea_maj' => 'Vložiť Æ',
	'barre_encadrer' => '[(Orámovať)] odsek',
	'barre_eo' => 'Vložiť œ',
	'barre_eo_maj' => 'Vložiť Œ',
	'barre_euro' => 'Vložiť symbol €',
	'barre_exposant' => 'Zmeniť text na &lt;sup&gt;horný index&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Špeciálne formátovanie',
	'barre_galerie' => 'Otvoriť galériu',
	'barre_gestion_anc_bulle' => 'Bublina s nápoveďou ku kotve',
	'barre_gestion_anc_caption' => 'Kotvy',
	'barre_gestion_anc_cible' => 'Cieľ kotvy',
	'barre_gestion_anc_inserer' => 'Zmeniť na kotvu',
	'barre_gestion_anc_nom' => 'Názov kotvy',
	'barre_gestion_anc_pointer' => 'Prepojiť s kotvou',
	'barre_gestion_caption' => 'Legenda a zhrnutie',
	'barre_gestion_colonne' => 'Počet stĺpcov',
	'barre_gestion_cr_casse' => 'Rozlišovať malé a veľké písmená',
	'barre_gestion_cr_changercasse' => 'Zmeniť malé písmená na veľké alebo opačne',
	'barre_gestion_cr_changercassemajuscules' => 'Zmeniť na veľké písmená',
	'barre_gestion_cr_changercasseminuscules' => 'Zmeniť na malé písmená',
	'barre_gestion_cr_chercher' => 'Vyhľadať',
	'barre_gestion_cr_entier' => 'Iba celé slová',
	'barre_gestion_cr_remplacer' => 'Nahradiť',
	'barre_gestion_cr_tout' => 'Nahradiť všetky',
	'barre_gestion_entete' => 'Hlavička',
	'barre_gestion_ligne' => 'Počet riadkov',
	'barre_gestion_taille' => 'Pevná veľkosť',
	'barre_glossaire' => 'Odkaz na [?Slovník] (Wikipédia)',
	'barre_gras' => '{{Tučné písmo}}',
	'barre_guillemets' => 'Dať do "dvojitých úvodzoviek"',
	'barre_guillemets_simples' => 'Dať do “jednoduchých úvodzoviek“',
	'barre_indenter' => 'Vynechať riadok',
	'barre_inserer_cadre' => 'Vložiť predformátovaný kód (rám)', # MODIF
	'barre_inserer_caracteres' => 'Vložiť špeciálne znaky',
	'barre_inserer_code' => 'Vložiť počítačový kód (kód)', # MODIF
	'barre_intertitre' => 'Zmeniť na {{{podnadpis}}}',
	'barre_italic' => '{Kurzíva}',
	'barre_langue' => 'Skratkový jzyk',
	'barre_lien' => 'Zmeniť na [hypertextový odkaz->http://...]',
	'barre_lien_externe' => 'Externý odkaz',
	'barre_lien_input' => 'Prosím, zadajte cieľ svojho hypertextového odkazu (môžete uviesť internetovú adresu v podobe http://www.mojastranka.sk alebo jednoducho číslo článku na tejto stránke).',
	'barre_liste_ol' => 'Nastaviť číslovaný zoznam',
	'barre_liste_ul' => 'Nastaviť zoznam',
	'barre_lorem_ipsum' => 'Vložiť falošný odsek',
	'barre_lorem_ipsum_3' => 'Vložiť tri falošné odseky',
	'barre_miseenevidence' => '[*Zvýrazniť*] text',
	'barre_note' => 'Zmeniť na [[poznámku pod čiarou]]',
	'barre_paragraphe' => 'Vytvoriť odsek',
	'barre_petitescapitales' => 'Zmeniť text na &lt;sc&gt;kapitálky&lt;/sc&gt;',
	'barre_poesie' => 'Upraviť ako &lt;poesie&gt;poéziu&lt;/poesie&gt;',
	'barre_preview' => 'Režim ukážky',
	'barre_quote' => '<quote>Citovať príspevok</quote>',
	'barre_stats' => 'Zobraziť štatistiku textu',
	'barre_tableau' => 'Vložiť/upraviť tabuľku (najprv ju označte)',

	// C
	'config_info_enregistree' => 'Nastavenia uložené',

	// E
	'editer' => 'Upraviť',
	'explication_barre_outils_public' => 'CSS a javascriptové skripty pre panely s nástrojmi
 (Rozšírenie Quill, Porte Plume) sa nachádzajú na verejne prístupnej stránke 
 a poskytujú panely nástrojov v diskusných fórach, vo verejnom prostredí crayonov alebo iných zásuvných modulov
 ak to ich nastavenia povoľujú.',
	'explication_barre_outils_public_2' => 'Môžete sa rozhodnúť, že nebudete spúšťať tieto skripty, aby ste odbremenili verejne prístupné stránky.
Preto bez ohľadu na nastavenia diskusných fóra, crayonov alebo zásuvných modulov
 sa na verejne prístupnej stránke automaticky nezobrazí žiaden panel s nástrojmi Porte Plume.',

	// I
	'info_barre_outils_public' => 'Verejné nástroje',
	'info_porte_plume_titre' => 'Nastavenia nástrojov',

	// L
	'label_barre_outils_public_non' => 'Na verejne prístupnej stránke nespúšťať skripty nástrojov',
	'label_barre_outils_public_oui' => 'Na verejne prístupnej stránke spúšťať skripty nástrojov',

	// V
	'voir' => 'Ukážka'
);
